@@ -3,8 +3,6 @@
 #' Calculate overall phylogenetic diversity and site similarity across multiple sites.
 #'
 #' @inheritParams hill_phylo
-#' @param phy_abund A matrix of phylogeny node and tips by community matrix derived
-#' from `dat_prep_phylo()`. Can be specified to speed up `hill_phylo_parti_pairwise()`.
 #' @param check_data Whether to check the community data and phylogeny. Default is `TRUE`.
 #' Can be set to `FALSE` to speed up `hill_phylo_parti_pairwise()`.
 #' @export
@@ -21,16 +19,20 @@
 #' hill_phylo_parti(comm, tree, q = 2)
 #'
 hill_phylo_parti <- function(comm, tree, q = 0, base = exp(1), rel_then_pool = TRUE,
-                             show_warning = TRUE, phy_abund = NULL, check_data = TRUE) {
+                             show_warning = TRUE, check_data = TRUE) {
     if(check_data){
         if (any(comm < 0))
             stop("Negative value in comm data")
-        # if(any(colSums(comm) == 0) & show_warning) warning('Some species in comm data were
-        # not observed in any site,\n delete them...') comm = comm[, colSums(comm) != 0] #
+        if(any(colSums(comm) == 0)){
+          if(show_warning)
+            warning('Some species in comm data were not observed in any site,\n delete them...')
+          comm = comm[, colSums(comm) != 0]
+         }
+
 
         comm_sp <- intersect(colnames(comm), tree$tip.label)
 
-        if (class(tree) != "phylo")
+        if (!inherits(tree, "phylo"))
             stop("tree must be an object with phylo as class")
         if (length(setdiff(tree$tip.label, comm_sp))) {
             if (show_warning)
@@ -52,11 +54,7 @@ hill_phylo_parti <- function(comm, tree, q = 0, base = exp(1), rel_then_pool = T
         }
     }
 
-    if(is.null(phy_abund)){
-        pabun <- dat_prep_phylo(comm, tree)
-    } else{ # already calculated
-        pabun <- phy_abund[, rownames(comm)]
-    }
+    pabun <- dat_prep_phylo(comm, tree)
 
     plength <- tree$edge.length
 
