@@ -22,7 +22,8 @@ hill_phylo_parti_pairwise <- function(comm, tree, q = 0, output = c("data.frame"
     pairs = c("unique", "full"), rel_then_pool = TRUE, .progress = TRUE,
     show_warning = TRUE, ...) {
     if (any(comm < 0)) stop("Negative value in comm data")
-    if (class(tree) != "phylo")
+    comm <- comm[, colSums(comm) > 0] # remove species have no occurrence
+    if (!inherits(tree, "phylo"))
         stop("tree must be an object with phylo as class")
     # clean phylogeny and community data
     sp_drop <- setdiff(tree$tip.label, colnames(comm))
@@ -42,7 +43,6 @@ hill_phylo_parti_pairwise <- function(comm, tree, q = 0, output = c("data.frame"
     if (rel_then_pool) {
         comm <- sweep(comm, 1, rowSums(comm, na.rm = TRUE), "/")  # relative abun
     }
-    pabund <- dat_prep_phylo(comm, tree) # pre-calculate node/tip by site matrix
 
     output <- match.arg(output)
     pairs <- match.arg(pairs)
@@ -57,7 +57,8 @@ hill_phylo_parti_pairwise <- function(comm, tree, q = 0, output = c("data.frame"
         if(.progress) utils::setTxtProgressBar(progbar, i)
         for (j in (i + 1):nsite) {
             o <- hill_phylo_parti(comm = comm[c(i, j), ], tree, q = q,
-                                  phy_abund = pabund, check_data = FALSE)
+                                  show_warning = FALSE,
+                                  check_data = TRUE)
             gamma_pair[i, j] <- o$PD_gamma
             gamma_pair[j, i] <- o$PD_gamma
             alpha_pair[i, j] <- o$PD_alpha
